#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::ShipmentOrder
# state        public
# description  ShipmentOrder element for the DHL Versenden shipping label request builder
#========================================================================================
package DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::ShipmentOrder;

use DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::Shipment;

use DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::LeafNodeHelper;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ShipmentOrder = DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::ShipmentOrder->new();
#----------------------------------------------------------------------------------------
# description  Object contructor.
#----------------------------------------------------------------------------------------
# return       $ShipmentOrder | DHL Versenden shipment order element object | object
#========================================================================================
sub new {
    my $class = shift;

    my $self  = bless {}, $class;

    return $self;
}

#========================================================================================
# function     assemble
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hShipmentOrder = $self->assemble();
#----------------------------------------------------------------------------------------
# description  Create the hash with shipment order data for the Shipping label request
#----------------------------------------------------------------------------------------
# input        $ShippingLabel | DHL Versenden shipping label object | object
# return       $hShipmentOrder | DHL Versenden shipment order element and warnings | ref.hash
#========================================================================================
sub assemble {
    my $self = shift;
    my ($ShippingLabel) = @_;

    my $LeafNodeHelper = DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::LeafNodeHelper->new();
    $LeafNodeHelper->addLeaf('sequenceNumber', $ShippingLabel->id());

    my @Warnings = @{$LeafNodeHelper->getWarnings()};

    my $hShipment = $self->_assembleShipment($ShippingLabel);
    push(@Warnings, @{$hShipment->{'nodeWarnings'}});

    return {
        'nodeData' => {
             'ShipmentOrder' => [ {
                 'sequenceNumber' => $LeafNodeHelper->getLeaf('sequenceNumber'),
                 %{$hShipment->{'nodeData'}},
                 # no optional PrintOnlyIfCodeable element (label only printable if address is valid)
             } ],
            'labelResponseType' => 'URL',
        },
        'nodeWarnings' => \@Warnings
    };
}

#========================================================================================
# Local methods
#========================================================================================
sub _assembleShipment {
    my $self = shift;
    my ($ShippingLabel) = @_;

    return DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::Shipment->assemble($ShippingLabel);
}

1;